<?php


/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 */

namespace Fullworks_Directory\Includes;

use Fullworks_Directory\Admin\Admin;
use Fullworks_Directory\FrontEnd\FrontEnd;
use Fullworks_Directory\Includes\Loader;
use Fullworks_Directory\Includes\i18n;
use Fullworks_Directory\Includes\Init;


class Core {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 */
	public function __construct($freemius) {

		$this->plugin_name = 'Fullworks_Directory';

		$this->version = FULLWORKS_DIRECTORY_PLUGIN_VERSION;

		$this->freemius = $freemius;

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_init_hooks();

	}

	/**
	 *
	 *  Loader. Orchestrates the hooks of the plugin.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */

		$this->loader = new Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *

	 */
	private function set_locale() {

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */

		$plugin_i18n = new i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 */


	private function define_admin_hooks() {

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */

		$plugin_admin = new Admin( $this->get_plugin_name(), $this->get_version() );


		$this->loader->add_action( 'widgets_init', $plugin_admin, 'register_custom_widgets' );

		$this->loader->add_action( 'cmb2_admin_init', $plugin_admin,'register_metaboxes' );


	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		$plugin_public = new FrontEnd( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );

		/**
		 * set templates for themes
		 */
		$this->loader->add_filter ( 'single_template', $plugin_public, 'single_template' );
		$this->loader->add_filter ( 'archive_template', $plugin_public, 'archive_template' );
		$this->loader->add_filter ( 'taxonomy_template', $plugin_public, 'taxonomy_template' );

		/**
		 * set template functions
		 */
		$this->loader->add_action( 'fd_entry_info_block_section', $plugin_public, 'entry_info_block_section' );






	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 */
	public function run() {
		$this->loader->run();
	}

	private function define_init_hooks(){
		/*
		 * Run init functions like CPT & shortcode
		 */
		$plugin_init = new Init( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'init', $plugin_init, 'custom_post_types' );
		$this->loader->add_action( 'widgets_init', $plugin_init, 'widgets_init',99 );

	}
	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 */
	public function get_loader() {
		return $this->loader;
	}

}
